==> kubernetes-model-certificates-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestConditionFluent.java <==
package io.fabric8.kubernetes.api.model.certificates;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface CertificateSigningRequestConditionFluent<A extends CertificateSigningRequestConditionFluent<A>> extends Fluent<A> {


    public String getLastUpdateTime();
    public A withLastUpdateTime(String lastUpdateTime);
    public Boolean hasLastUpdateTime();
    public A withNewLastUpdateTime(String arg1);
    public A withNewLastUpdateTime(StringBuilder arg1);
    public A withNewLastUpdateTime(StringBuffer arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);
}

==> kubernetes-model-certificates-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestConditionFluent.java <==
package io.fabric8.kubernetes.api.model.certificates;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface CertificateSigningRequestConditionFluent<A extends CertificateSigningRequestConditionFluent<A>> extends Fluent<A> {


    public String getLastTransitionTime();
    public A withLastTransitionTime(String lastTransitionTime);
    public Boolean hasLastTransitionTime();
    public A withNewLastTransitionTime(String arg1);
    public A withNewLastTransitionTime(StringBuilder arg1);
    public A withNewLastTransitionTime(StringBuffer arg1);
    public String getLastUpdateTime();
    public A withLastUpdateTime(String lastUpdateTime);
    public Boolean hasLastUpdateTime();
    public A withNewLastUpdateTime(String arg1);
    public A withNewLastUpdateTime(StringBuilder arg1);
    public A withNewLastUpdateTime(StringBuffer arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(String arg1);
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(StringBuffer arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);
}
